/**
 * Copyright (c) 2024-2025 National Fundamental Software of China Co., Ltd.
 * 
 * You should have find a copy of NFSChina License. If not, please contact us 
 * by email <os_support@nfschina.com>  
 * 
**/
#ifndef FDK_WALLPAPER_H
#define FDK_WALLPAPER_H

#include <stddef.h>

#ifdef __cplusplus
extern "C" {
#endif


/**
 * @brief 壁纸模式类型,定义了壁纸的应用模式，适用于全局或单个用户。
 */
typedef enum {
    WALLPAPER_MODE_TYPE_GLOBAL = 0,          /**< 全局模式：适用于所有用户 */
    WALLPAPER_MODE_TYPE_USER,                /**< 用户模式：仅应用于当前用户 */
    WALLPAPER_MODE_TYPE_INVALID = -1         /**< 无效模式 */
} FDKWallpaperModeType;

/**
 * @brief 壁纸显示模式,定义了壁纸的显示方式，例如平铺、拉伸等。
 */
typedef enum {
    WALLPAPER_DISPLAY_MODE_TILE = 0,       /**< 平铺模式 */
    WALLPAPER_DISPLAY_MODE_STRETCH,        /**< 拉伸模式 */
    WALLPAPER_DISPLAY_MODE_CENTER,         /**< 居中模式 */
    WALLPAPER_DISPLAY_MODE_FIT,            /**< 适应模式（图像保持比例，适应屏幕） */
    WALLPAPER_DISPLAY_MODE_FILL,           /**< 填充模式（图像保持比例，填充屏幕） */
    WALLPAPER_DISPLAY_MODE_INVALID = -1    /**< 无效模式 */
} FDKWallpaperDisplayMode;


/**
 * @brief 设置桌面壁纸。
 * @param[in] wallpaper_path 指向壁纸文件路径的字符串，路径为绝对路径。
 * @return 成功返回 0，失败返回错误码。
 * @note 确保传入的文件路径有效，并且是系统支持的图片格式（如 PNG、JPG、BMP 等）。
 */
int fdk_wallpaper_set(const unsigned char *wallpaper_path);

/**
 * @brief 获取当前壁纸路径。
 * @param[out] wallpaper_path 指向存储壁纸路径的字符串指针，调用者需要分配内存空间来存储路径。
 * @param[in] size 提供的内存空间的大小，单位为字节。
 * @return 成功返回 0，失败返回错误码。
 * @note 确保传入的 wallpaper_path 指针有效，并且提供足够的内存空间来存储路径。
 */
int fdk_wallpaper_get_path(unsigned char *wallpaper_path, size_t size);

/**
 * @brief 列出系统中所有可用的壁纸文件路径。
 * @param[out] wallpaper_paths 指向存放壁纸路径的字符串数组的指针，由API内部分配内存空间。
 * @param[out] count 指向存放壁纸数量的指针，调用者分配内存。
 * @return 成功返回 0，失败返回错误码。
 * @note 确保传入的 count 指针有效。
 * TODO: 待实现
 */
int fdk_wallpaper_get_all(unsigned char ***wallpaper_paths, int *count);

/**
 * @brief 移除指定桌面壁纸。
 * @param[in] wallpaper_path 指向壁纸文件路径的字符串，表示要移除的壁纸路径。
 * @return 成功返回 0，失败返回错误码。
 * @note 确保传入的 wallpaper_path 指定的文件路径有效。
 * TODO: 待实现
 */
int fdk_wallpaper_remove(const unsigned char *wallpaper_path);

/**
 * @brief 获取当前壁纸模式（全局模式或用户模式）。
 * @return 当前壁纸模式：
 * - `WALLPAPER_MODE_TYPE_GLOBAL`：全局模式，适用于所有用户。
 * - `WALLPAPER_MODE_TYPE_USER`：用户模式，仅应用于当前用户。
 * - `WALLPAPER_MODE_INVALID`：无效模式（表示获取失败）。
 * TODO: 待实现
 */
FDKWallpaperModeType fdk_wallpaper_get_mode(void);

/**
 * @brief 重置壁纸为默认壁纸。
 * @return 成功返回 0，失败返回错误码。
 *  
 */
int fdk_wallpaper_set_default(void);

/**
 * @brief 将水印图像添加到系统目录，以供用户在设置壁纸水印时选择。
 * @param[in] watermark_image 水印图像的路径（本地路径）。
 * @return 成功返回 0，失败返回错误码。
 * @note 确保传入的水印图像路径有效，并且该路径指向的文件是一个有效的图像文件。
 * TODO: 待实现
 */
int fdk_wallpaper_add_watermark(const unsigned char *watermark_image);

/**
 * @brief 设置壁纸水印。
 * @param[in] watermark_name 水印图像的名称（系统目录中的文件名）。当为 NULL 时表示去除水印。
 * @param[in] scale 水印图像的缩放比例，范围为 0.1 到 1.0（缩小或放大）。
 * @return 成功返回 0，失败返回错误码。
 * @note 确保传入的水印图像名称有效，并且 scale 在合理范围内（0.1 到 1.0）。
 * TODO: 待实现
 */
int fdk_wallpaper_set_watermark(const unsigned char *watermark_name, float scale);

/**
 * @brief 从系统水印列表中移除指定的水印图像。
 * @param[in] watermark_name 水印图像的名称（系统目录中的文件名）。
 * @return 成功返回 0，失败返回错误码。
 * @note 确保传入的水印图像名称有效，并且该水印图像已存在于水印列表中。
 * TODO: 待实现
 */
int fdk_wallpaper_remove_watermark(const unsigned char *watermark_name);


#ifdef __cplusplus
}
#endif

#endif // FDK_WALLPAPER_H